@@ -2,8 +2,7 @@
 from django.db import models
 from django.db.models.signals import post_init
 from django.db.models.fields import FieldDoesNotExist
-import sys
-import os
+
 from image.video_field import VideoField
 from image.forms import ImageCenterFormField
 
